@@ -1,5 +1,3 @@
-<?php
-?>
 <form action="<?php echo getModuleAdminSelfPath()?>" method="post">
 <?php csrf_token_html();?>
 <p>
@@ -13,4 +11,8 @@
 		<label for="sql_console_replace_placeholders"><?php translate("sql_console_replace_placeholders")?></label>
 	</p>
 	<input type="submit" value="<?php translate("sql_console_execute");?>">
-</form>
\ No newline at end of file
+</form>
+<?php 
+BackendHelper::enqueueEditorScripts();
+combinedScriptHtml();
+?>
\ No newline at end of file
